import Logger from 'js-logger';
/**
 * Broadcasts logs to all clients
 */
export class BroadcastLogger {
    constructor(clients) {
        this.clients = clients;
        this.TRACE = Logger.TRACE;
        this.DEBUG = Logger.DEBUG;
        this.INFO = Logger.INFO;
        this.TIME = Logger.TIME;
        this.WARN = Logger.WARN;
        this.ERROR = Logger.ERROR;
        this.OFF = Logger.OFF;
    }
    trace(...x) {
        console.trace(...x);
        this.clients.forEach((p) => p.clientProvider.trace(...x));
    }
    debug(...x) {
        console.debug(...x);
        this.clients.forEach((p) => p.clientProvider.debug(...x));
    }
    info(...x) {
        console.info(...x);
        this.clients.forEach((p) => p.clientProvider.info(...x));
    }
    log(...x) {
        console.log(...x);
        this.clients.forEach((p) => p.clientProvider.log(...x));
    }
    warn(...x) {
        console.warn(...x);
        this.clients.forEach((p) => p.clientProvider.warn(...x));
    }
    error(...x) {
        console.error(...x);
        this.clients.forEach((p) => p.clientProvider.error(...x));
    }
    time(label) {
        console.time(label);
        this.clients.forEach((p) => p.clientProvider.time(label));
    }
    timeEnd(label) {
        console.timeEnd(label);
        this.clients.forEach((p) => p.clientProvider.timeEnd(label));
    }
    setLevel(level) {
        // Levels are not adjustable on this level.
    }
    getLevel() {
        // Levels are not adjustable on this level.
        return Logger.INFO;
    }
    enabledFor(level) {
        // Levels are not adjustable on this level.
        return true;
    }
}
//# sourceMappingURL=BroadcastLogger.js.map